summaryrefslogtreecommitdiff
path: root/plugins/sudo
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/sudo')
-rw-r--r--plugins/sudo/README.md57
-rw-r--r--plugins/sudo/sudo.plugin.zsh18
2 files changed, 72 insertions, 3 deletions
diff --git a/plugins/sudo/README.md b/plugins/sudo/README.md
new file mode 100644
index 000000000..25eb85829
--- /dev/null
+++ b/plugins/sudo/README.md
@@ -0,0 +1,57 @@
+# sudo
+
+Easily prefix your current or previous commands with `sudo` by pressing <kbd>esc</kbd> twice
+
+## Enabling the plugin
+
+1. Open your `.zshrc` file and add `sudo` in the plugins section:
+
+ ```zsh
+ plugins=(
+ # all your enabled plugins
+ sudo
+ )
+ ```
+
+2. Restart your shell or restart your Terminal session:
+
+ ```console
+ $ exec zsh
+ $
+ ```
+
+## Usage examples
+
+### Current typed commands
+
+Say you have typed a long command and forgot to add `sudo` in front:
+
+```console
+$ apt-get install build-essential
+```
+
+By pressing the <kbd>esc</kbd> key twice, you will have the same command with `sudo` prefixed without typing:
+
+```console
+$ sudo apt-get install build-essential
+```
+
+### Previous executed commands
+
+Say you want to delete a system file and denied:
+
+```console
+$ rm some-system-file.txt
+-su: some-system-file.txt: Permission denied
+$
+```
+
+By pressing the <kbd>esc</kbd> key twice, you will have the same command with `sudo` prefixed without typing:
+
+```console
+$ rm some-system-file.txt
+-su: some-system-file.txt: Permission denied
+$ sudo rm some-system-file.txt
+Password:
+$
+```
diff --git a/plugins/sudo/sudo.plugin.zsh b/plugins/sudo/sudo.plugin.zsh
index e3ba39918..f405b025f 100644
--- a/plugins/sudo/sudo.plugin.zsh
+++ b/plugins/sudo/sudo.plugin.zsh
@@ -2,7 +2,7 @@
# Description
# -----------
#
# sudo will be inserted before the command
#
# ------------------------------------------------------------------------------
# Authors
@@ -14,8 +14,20 @@
sudo-command-line() {
[[ -z $BUFFER ]] && zle up-history
- [[ $BUFFER != sudo\ * ]] && LBUFFER="sudo $LBUFFER"
+ if [[ $BUFFER == sudo\ * ]]; then
+ LBUFFER="${LBUFFER#sudo }"
+ elif [[ $BUFFER == $EDITOR\ * ]]; then
+ LBUFFER="${LBUFFER#$EDITOR }"
+ LBUFFER="sudoedit $LBUFFER"
+ elif [[ $BUFFER == sudoedit\ * ]]; then
+ LBUFFER="${LBUFFER#sudoedit }"
+ LBUFFER="$EDITOR $LBUFFER"
+ else
+ LBUFFER="sudo $LBUFFER"
+ fi
}
zle -N sudo-command-line
# Defined shortcut keys: [Esc] [Esc]
-bindkey "\e\e" sudo-command-line
+bindkey -M emacs '\e\e' sudo-command-line
+bindkey -M vicmd '\e\e' sudo-command-line
+bindkey -M viins '\e\e' sudo-command-line
@@ -2,7 +2,7 @@
# -----------
#
-# sudo will be inserted before the command
+# sudo or sudoedit will be inserted before the command
#
# ------------------------------------------------------------------------------